@@ -24,18 +24,16 @@
  *    Michael Meeks <michael@ximian.com>
  *    Morten Welinder <terra@diku.dk>
  *
- *  Copyright (C) 2000-2001 Ximian Inc. and authors
+ *  Copyright (C) 2000-2003 Ximian Inc. and authors
  */
 
-#define __GNOME_FONT_C__
-
+#include <config.h>
 #include <math.h>
-
 #include <stdlib.h>
-#include <libart_lgpl/art_affine.h>
-
 #include <string.h>
-#include "gnome-font-private.h"
+
+#include <libart_lgpl/art_affine.h>
+#include <libgnomeprint/gnome-font-private.h>
 
 enum {
 	PROP_0,
@@ -294,7 +292,7 @@ gnome_font_find_closest (const guchar *name, gdouble size)
 
 	if (!face) {
 		/* fixme: */
-		face = gnome_font_face_find_closest ("Helvetica");
+		face = gnome_font_face_find_closest ("Sans Regular");
 		g_return_val_if_fail (face != NULL, NULL);
 	}
 
@@ -664,6 +662,43 @@ gnome_font_get_pango_description (const GnomeFont *font, gdouble dpi)
 	return desc;
 }
 
+/**
+ * gnome_font_lookup_default:
+ * @font: 
+ * @unicode: 
+ *
+ * Get the glyph number corresponding to a given unicode
+ * 
+ * Return Value: glyph number, -1 if it is not mapped
+ **/
+gint
+gnome_font_lookup_default (GnomeFont *font, gint unicode)
+{
+	g_return_val_if_fail (font != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_FONT (font), -1);
+
+	return gnome_font_face_lookup_default (font->face, unicode);
+}
+
+static gboolean
+gf_free_outline (gpointer a, gpointer b, gpointer data)
+{
+	g_free (b);
+
+	return TRUE;
+}
+
+
+
+/**
+ * gnome_font_get_width_utf8:
+ * @font: 
+ * @s: 
+ * 
+ * To be deprecated soon
+ * 
+ * Return Value: 
+ **/
 double
 gnome_font_get_width_utf8 (GnomeFont *font, const char *s)
 {
@@ -674,6 +709,16 @@ gnome_font_get_width_utf8 (GnomeFont *font, const char *s)
 	return gnome_font_get_width_utf8_sized (font, s, strlen (s));
 }
 
+/**
+ * gnome_font_get_width_utf8_sized:
+ * @font: 
+ * @text: 
+ * @n: 
+ * 
+ * To be depreacated soon
+ * 
+ * Return Value: 
+ **/
 double
 gnome_font_get_width_utf8_sized (GnomeFont *font, const char *text, int n)
 {
@@ -695,26 +740,3 @@ gnome_font_get_width_utf8_sized (GnomeFont *font, const char *text, int n)
 	
 	return width * 0.001 * font->size;
 }
- 
-/* Get the glyph number corresponding to a given unicode, or -1 if it
-   is not mapped. */
-gint
-gnome_font_lookup_default (GnomeFont *font, gint unicode)
-{
-	g_return_val_if_fail (font != NULL, -1);
-	g_return_val_if_fail (GNOME_IS_FONT (font), -1);
-
-	return gnome_font_face_lookup_default (font->face, unicode);
-}
-
-static gboolean
-gf_free_outline (gpointer a, gpointer b, gpointer data)
-{
-	g_free (b);
-
-	return TRUE;
-}
-
-
-
-
